#
# spec file for package python-xkcdpass
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-xkcdpass
Version:        1.19.8
Release:        2.3
Summary:        A flexible and scriptable password generator which generates strong passphrases
License:        BSD-3-Clause
URL:            https://github.com/redacted/XKCD-password-generator
Source:         https://files.pythonhosted.org/packages/source/x/xkcdpass/xkcdpass-%{version}.tar.gz
Patch0:         fix-test-assertion-methods.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
A flexible and scriptable password generator which generates strong passphrases,
inspired by XKCD 936 (https://xkcd.com/936/)

%prep
%autosetup -p1 -n xkcdpass-%{version}
# Remove the shebang
sed -i -e '1d' xkcdpass/xkcd_password.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/xkcdpass
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#redacted/XKCD-password-generator#138
pytest_python310_ignore="not test_entropy_printout_valid_input"
pytest_python311_ignore="not test_entropy_printout_valid_input"
%pytest -k "${pytest_$python_ignore}"

%post
%python_install_alternative xkcdpass

%postun
%python_uninstall_alternative xkcdpass

%files %{python_files}
%license LICENSE*
%doc README.rst
%python_alternative %{_bindir}/xkcdpass
%{python_sitelib}/xkcdpass
%{python_sitelib}/xkcdpass-%{version}.dist-info

%changelog
* Fri Mar 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-test-assertion-methods.patch, use correct assertion
  methods.
- Switch to autosetup and pyproject macros.
* Wed Dec 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.19.8:
  * Enables `python -m xkcdpass` usage
  * Adds Swedish wordlist, improvements to test suite,
    improvements to setup.py (excludes examples from install)
  * Fixes randomly failing unit test
  * Adds "as-is" option for case
  * Makes randomised delimiters behavior consistent with fixed
    delimeters
* Mon Feb 20 2023 Daniel Garcia <daniel.garcia@suse.com>
- Skip failing test python 3.11 (gh#redacted/XKCD-password-generator#138).
* Mon Mar  7 2022 Dirk Müller <dmueller@suse.com>
- update to 1.19.3:
  * Restore a randomly sampled version of eff_large_de wordlist
* Wed Jan 12 2022 Matej Cepl <mcepl@suse.com>
- Skip failing test (gh#redacted/XKCD-password-generator#138).
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros
* Sun May 23 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 1.19.2
  * Added randomised delimiters
  * Initial support for multiple wordfiles
* Fri Jan 29 2021 Ben Greiner <code@bnavigator.de>
- Fix singlespec
* Sat Dec 19 2020 İsmail Dönmez <idoenmez+factory@suse.de>
- Update to version 1.17.6
  * No changelog upstream
* Wed May 13 2020 Ismail Dönmez <idonmez@suse.com>
- Add Requires on python-setuptools
* Thu Nov 21 2019 Ismail Dönmez <idonmez@suse.com>
- Initial release for build.opensuse.org
